---
title: "NFDI4Earth OneStop4All documentation"
subtitle: "Description of the development process for the portal features and functionalities"
keywords: ["NFDI", "NFDI4Earth", "NFDI4Earth OneStop4All", "NFDI4Earth OS4A"]
author:
  - name: "Ivonne Anders"
    email: "anders@dkrz.de"
    orcid: "0000-0001-7337-3009"
  - name: "Sibylle Hassler"
    orcid: "0000-0001-5411-8491"
  - name: "Marie Ryan"
    orcid: "0000-0002-7890-9631"
  - name: "Hannes Thiemann"
    orcid: "0000-0002-2329-8511"
  - name: "Peter Braesicke"
    orcid: "0000-0003-1423-0619"
date: "2023-10"
lang: en-GB
doi: "10.5281/zenodo.10210546"
abstract: |
  This document describes the development of the OneStop4All, the central
  entry point into the resources of the NFDI4Earth. The basis for these
  developments was the work of the Measure 2.1 with the support of the
  expert group \"User\", during the period from August 2022 to May 2023.
  Additionally, the participants of the NFDI4Earth plenum in June 2023
  contributed to the process with ideas and requirements. The
  documentation first gives a short introduction into the aim of the
  OneStop4All portal and the community engagement. Then we describe the
  development process and the used methods in more detail, including a
  description of the individual steps to create the mock-ups, i.e. the
  basis for implementation of the portal.
toc: true
figPrefix: Fig.
tblPrefix: Tab.
secPrefix: ""
#include-preamble: |
#  \captionsetup[figure]{labelformat=empty}
# header-left: ... # too long title
lof: true
lot: true
---

# Aim of the OneStop4All

The OneStop4All is the web portal which provides the central entry point
to all resources in the NFDI4Earth. Any inquiries and searches from the
Earth System Science (ESS) community and other interested people will be
handled within this portal which is built upon the other NFDI4Earth
components. The OneStop4All receives the searchable content from the
KnowledgeHub, the LivingHandbook and EduTrain, with the metadata to all
content being stored in the KnowledgeHub. The portal also serves as
entry point to the EduTrain Learning Management System and is connected
to the ticket system of the User Support Network (USN) so that any
requests that require further assistance can be forwarded. The portal
also offers a login area that can be linked to a user management system.
In the first version the login area may be mainly useful for direct
access and contribution to the KnowledgeHub, whereas later on the profile
functionalities are envisioned to also encompass saving searches and
workflows (Degbelo et al. 2023).

Within the NFDI4Earth consortium organisation, the portal structure and
functionalities are mainly developed by Measure 2.1 (\"OneStop4All\"),
while the technical implementation and content management system,
feedback and support are the responsibility of Measure 4.3. (Bernhard et
al. 2021)\
In addition to the collaborative effort of these groups, including the
ESS in the development is of paramount importance for the success of
NFDI4Earth. Our approach to achieve this is described in the following
section.

# For the community with the community

The NFDI4Earth wants to support the ESS community in providing a portal
(the OneStop4All) that not only holds relevant and linked resources in
one place, but which is intuitive and easy to use for a wide range of
users. A good user experience and \"customer\" satisfaction requires
understanding user behaviour, goals, motivations and expectations and
incorporating this knowledge into every stage of the design process.

To achieve this, we use methods from user-centred design (UCD),
complemented with knowledge and experience in various ESS domains from
the NFDI4Earth consortium members, their extended scientific networks
and by involving the community directly at the first NFDI4Earth plenum.

The user-centred design process typically involves the following key
activities (Nielsen, 1992 and Butz and Krüger, 2017):

(a) **User Research:** Conducting research to understand the users\'
    characteristics, goals, and context of use. This may involve
    methods such as interviews, surveys, observations, and user
    testing.

(b) **User Requirements:** Identifying and documenting the requirements
    and goals of the users. This helps in defining design objectives
    and guiding the design process.

(c) **Conceptual Design:** Generating design concepts or ideas based on
    the user requirements. This stage focuses on brainstorming and
    exploring different design possibilities.

(d) **Prototyping:** Creating prototypes or mock-ups of the design to
    gather feedback and evaluate usability. Prototypes can be
    low-fidelity (e.g., sketches or wireframes) or high-fidelity
    (e.g., interactive prototypes).

(e) **Evaluation:** Testing the prototypes with users to assess
    usability, gather feedback, and identify areas for improvement.
    This may involve methods such as usability testing, heuristic
    evaluations, or user feedback surveys.

(f) **Iterative Design:** Incorporating the feedback and insights gained
    from evaluation into the design. This iterative process helps
    refine and improve the design based on user needs and preferences.

(g) **Implementation:** Developing the final product or service based on
    the refined design. User-centred design principles can also
    inform decisions during the development process.

(h) **User Testing:** Conducting usability tests with the final product
    to ensure it meets the users\' needs and is easy to use. This step
    helps identify any remaining issues or areas for optimisation.

In the development period included in this document, we covered
approximately steps a) through d). In the following, we describe the
detailed steps that were necessary to achieve this.

\newpage

# From user requirements to mockups

The following steps describe the process of collecting user requirements
until a set of mock-ups was created. We also highlight how these steps
influenced development in other NFDI4Earth products and how the
community was involved.

## Step 1: Collecting user requirements

The NFDI4Earth portal is meant to explicitly target the needs of the
diverse ESS community. Therefore we collected user stories that should
describe the necessary content and functionalities of the OneStop4All.
They should conform to the format \"Persona (with certain background and
education level) -- has a specific requirement/need with regard to the
portal -- for a certain reason/to achieve a certain goal\".

We created a working group across the different NFDI4Earth Task Areas to
bring together all people whose tasks involved users and to address the
envisioned requirements and interactions (expert group \"Users\").
Within this group and the Measure 2.1 we initiated the collection of the
abovementioned user stories, keeping the needs of scientists from our
own experience and that of our colleagues and networks in mind. The call
to contribute user stories was also extended to the NFDI4Earth
participants to get a broader coverage of different disciplines and
requirements. Finally, we included the attendants at the N4E plenum 2022
in Dresden in the survey and recorded additional user stories they
offered, both as a response to a poster and as results from a break-out
session. After including these as well, we had 182 user stories and
requirements.

The process and the collection was discussed various times during the
expert group \"Users\" meetings, the TA2 meetings and the co-app
meetings. Furthermore, in separate meetings with the KnowledgeHub,
LivingHandbook and EduTrain groups, the compatibility of the user
stories to these products and the necessary developments in each product
to satisfy the user needs were discussed.

## Step 2: Grouping user requirements to support categories

The categorisation of support classes based on the collected user
stories and user requirements is important in two ways:

**For the USN:** One challenge in recording customer requests is the
classification of the ticket to a certain topic category, which is
necessary to assess the priority and the associated queue leading to an
expert where the ticket can be answered. In most support ticketing
systems, including OTRS, the system chosen by the Measure 2.2 (USN),
such a classification of tickets is used to assign tickets to the
experts, and it can also be used to analyse the requests and assess the
support quantity and quality.

**For the design of the OneStop4All:** Classifying the user stories and
requirements makes it easier to structure and design the OneStop4All, as
each category requires specific features and functionalities which in
turn affects implementation. Monitoring the user behaviour on the
portal, the categories also help to identify support gaps that should be
improved by including more content or different functionalities.

The user stories and requirements were grouped thematically and assigned
to categories. In total, **9 categories** could be derived (Lorenz et
al., 2023):

1. *Repositories/Archives:*

   > This category is strongly related to user stories which particularly
   > include the topics of data search and publication. There are a variety
   > of repositories that have different thematic foci but also different
   > requirements for (meta) data. Users are supported and advised by the
   > OneStop4All and the USN in finding a suitable repository for data
   > search or data publication, but also in how data must be made
   > available or prepared.
1. *Information on topics and tools:*

   > The underlying user stories and requirements of this category deal
   > primarily with the search of information on various research data
   > management (RDM) and data science topics, but also descriptions of
   > e.g. software or tools.
   >
   > The category can also be renamed to \"Information on RMD and Data
   > Science topics and on different types of content\" to also cover
   > information on organisations, services, etc.
1. *Tools/Software:*

   > Tools/software can affect very many areas. The aim of the OneStop4All
   > and the USN is to help users find suitable software or tools for their
   > specific use case, and possibly also to support them in their correct
   > use. However, the OneStop4All and USN do not provide IT support.
1. *Services/Infrastructures:*

   > The category \"Services\" concerns users who want to know where they
   > can obtain computing and data resources and corresponding services.
   > Topics include virtual research environments, computational resources
   > and storage (near computational/cloud resources, stand-alone or
   > exchange platform) but also web services and use of APIs.
   >
   > Due to generally applicable definitions for the term services, there
   > is potential here to merge this category to the \"Tools/Software\"
   > category. However, the current subdivision is useful in the USN ticket
   > system.
1. *Data and analysis:*

   > This category bundles support requests that involve questions about
   > datasets and their analysis or reuse. These requests or applications
   > are very discipline- and subject-specific. It can be estimated that
   > questions and requirements that fall into this area are the most
   > difficult to answer or fulfil.
1. *Participation in N4E:*

   > Questions about contacting, participating in or promoting the
   > NFDI4Earth fall into this category. These questions should be answered
   > as completely as possible by the OneStop4All in order to relieve the
   > USN.
1. *Community and networking:*

   > This category deals with requests to networks or the community, such
   > as looking for contact persons, a forum for exchange, searching for
   > experts in a specific field, or for researchers in the same subject
   > area.
1. *Educational materials:*

   > Users need educational materials for different reasons. These include
   > learning about research data management in general, or with specific
   > focus on ESS data, but also materials for data analysis, best
   > practices, and other topics in their research field may be required.
   > Teachers could be looking for reusable materials in these areas.
1. *Re-direction to other NFDIs:*

   > However, there are also questions that cannot be answered by
   > NFDI4Earth because the topic is out of scope of ESS. Here, the
   > OneStop4All and the USN should offer appropriate references and
   > suggestions where the users might find support.

The categories were further refined in the development process and also
used as discussion basis with other products to assess necessary content
and metadata description.

## Step 3: Identifying proto-personas

To better understand users\' needs, experiences, behaviours and goals,
creating personas to represent these users can help. According to Dam
and Siang (2020) and Jacobsen (2017), personas are fictional characters
based on research, to represent different types of users who might use
the services, a product, a website or a brand in a similar way. They can
be used as a common image to personifying a specific group of users
(Cooper, 1999).

There are different theoretical models for personas and what they should
be based on. There are also different ways to apply personas in
practice. Thus, there is no \"best way\" to use personas and it depends
on the situation. Although personas as a basic method has become the
scientific standard in the field of human-centred design (Pruitt and
Adlin, 2005), some problems have been identified in the scientific and
practical discourse. Donald Norman, for example, suggests working with
ad hoc personas based on the development team\'s experience and prior
knowledge with the respective target groups in order to save costs as
much as possible (Norman, 2018).

We examined approaches and concepts regarding personas that are being
used in other NFDI consortia and analysed their applicability for
NFDI4Earth. NFDI4Ing, for example, went into a user research process
through surveys and interviews in the run-up to the project , coming up
with data-based personas (Schmitt et al., 2020). As this was not
possible in NFDI4Earth, we used the existing knowledge of the NFDI4Earth
staff in terms of their diverse backgrounds and prior experience with
different target groups to create proto-personas according to Norman
(2018). This approach was also followed by the NFDI4Biodiversitiy
consortium and their proto-personas are actively being used when
creating the services for the users. Proto-personas are described in
less detail compared to data-based personas and can always be modified
or extended in the development process of products or services.

We initially described 10 proto-personas, which could be further reduced
to 7 due to similar assigned roles, age ranges and other
characteristics. Gender and ethnic aspects were also included. The
personas also covered the range of users we encountered in the user
stories.

A brief overview of the developed resulting proto-personas is given in
[@tbl:personas].
[@fig:personastew; @fig:personasci] give the two examples of the personas.
Here we give
details of name, gender and role, as well as a short statement and
characteristics of the persona. The complete persona descriptions can be
found the respective publication (Anders et al. 2023).

\scriptsize

Name       Gender    Age   Role
---------- --------- ----- ----------------------
Paulo      male      45    The Senior Scientist
Mary       female    34    The PostDoc
Jemal      male      30    The PhD Student
Burkhard   male      64    The Professor
Eya        diverse   22    The Master Student
Valerie    female    42    The Data Steward
Nisrin     female    48    The Private Person

: Overview of the proto-personas {#tbl:personas}

\normalsize

In the literature or in practice, photographs or drawings are often
assigned to the personas for visualisation. This makes it easier for the
team to identify with the personas. In public discourse, however, this
should be viewed critically. Prejudices or false attributions can
quickly be made. Therefore, we have chosen a representation that is more
neutral and is without faces.

Potential for further reducing the number of personas and thus
simplifying the handling could be achieved with the personas Paulo,
Mary, Jemal and Burkhard. All of them have a scientific background and
could partly speak for one of the other groups. For example, Paulo, who
also teaches at the university, could also see the OneStop4All from the
perspective of his post-doc colleagues or PhD students. Eya, as a
Master\'s student, should be kept as a separate persona, despite
belonging to the university, because it is based on different topics and
also a different type of action. The reduction can also happen
organically in the development process if it turns out that some
personas are rarely used (as was the case in NFDI4Biodiversity).

![Example of proto-persona, their characteristics, statements and behaviour: Data Steward.](persona-data-steward.png){#fig:personastew width="4.958350831146107in"
height="1.1145833333333333in"}

![Example of proto-persona, their characteristics, statements and behaviour: Senior Scientist.](persona-senior-scientist.png){#fig:personasci width="4.958350831146107in"
height="1.1145833333333333in"}

## Step 4: Defining user scenarios

While personas form the basis for a good representation of the users,
the features and functionalities that need to be developed can be
assessed by defining detailed user scenarios.

User scenarios are short narratives (they have a plot) that show how a
user uses the product or service to achieve their goal. User scenarios
address motivations, needs and barriers in the context of how users
would interact with the design, product or feature. In short, scenarios
describe in detail what users would likely experience if they were using
an ideal solution.

Representatives of all NFDI4Earth components (LivingHandbook, EduTrain,
KnowledgeHub, Networking, Academy, Pilots etc.) were part in the expert
group \"Users\" to create user scenarios. On the basis of the existing
user stories, partly combining them, 10 user scenarios were created to
exemplify the use of the OneStop4All. The scenarios describe in detail
the procedure of the proto-personas when fulfilling or achieving tasks
and can be found in Appendix&nbsp;[@sec:scenarios].

User scenarios are the basis for implementation. They contain
functionalities of varying degrees of difficulty. They may also contain
innovations that cannot be implemented during the course of the project
but are envisioned in the future. During implementation, the scenarios
are adapted or parts are discarded. The other NFDI4Earth products, such
as the LivingHandbook, also have their own scenarios that e.g.
specifically concern the handling of articles for authors and the
editorial process.

## Step 5: Portal evaluation

After developing the required functionalities for the OneStop4All from
the user stories and requirements, the team of Measure 2.1 evaluated a
range of existing portals to check their functionality and usability.
This evaluation was meant to provide examples for the portal
development, of features that are appealing and should be adopted in the
OneStop4All, as well as features that are not working properly and
should be avoided.

The portals we evaluated ranged from established portals of large ESS
data (and information) providers (e.g. NOAA OneStop, NASA EarthData,
ENVRI-hub, EOSC portal, ICOS data, EPOS Data portalMarine Data Portal,
\...), portals of other NFDIs (e.g. NFDI4Biodiversity, NFDI4Chem,
DataPlant, \...), community portals (e.g. CLM-Community Portal,
Klimainformationssystem Bayern) and some commercial portals (e.g.
Spotify).

We created a spreadsheet (see [@fig:evaluationspreadsheet]) and evaluated a range of criteria for
the portals, based on Jakobson (2017) and additional criteria that were
considered important functionalities based on the user stories, using
colour codes to highlight preferences. These criteria ranged from
assessing the content, the focus on the target group, design,
information architecture as the more general topics to the existence of
a guided navigation, how a login area could be provided, how
news/calendar is implemented, bilinguality, how help is provided
(helpdesk, FAQ), etc. as more specific desired functionalities for the
OneStop4All. Due to time constraints not all fields of the spreadsheet
were meticulously filled, but the portals were checked and general
impressions according to the different criteria were noted, as well as
outstanding features that should be copied.

![Screenshot of a part of the portal evaluation spreadsheet.](evaluation-spreadsheet.png){#fig:evaluationspreadsheet width="5.982659667541557in" height="2.15625in"}

The evaluation yielded the following features that we considered
important for the functionalities and design of the OneStop4All:

- Topic-based entry buttons on home page into different content
  categories

- Prominent search bar with filters

- Well defined and sensible filter options; clear indication which
  search filters are active

- First page of search result across multiple resources: Result list
  summarised into resource categories, show first few results in each
  category

- Links to related content

- Guided navigation that considers both experienced and
  non-experienced users

- Information and tutorials to guide first-time users

- Easy access to help as helpdesk and/or FAQs

- Clean design without over-packed web pages

## Step 6: Defining different navigation and search options in the portal

The OneStop4All should be useful and intuitive for users from ESS of all
levels of knowledge and experience with data management or portals.
Therefore we defined various ways to access the content of the N4E
through the portal:

- A prominent search bar is situated at the top of the main page so
  that users who are accustomed to searching via the omnipresent
  search engines with the help of keywords and search strings have a
  direct entry, followed by the usual view of filters and results
  lists.

- A section with clickable panels for topic-based entry points. The
  topics are chosen according to their relevance (first amount of
  related user stories, in later versions this might shift according
  to the evaluation of the support needs from the User Support
  Network. The topic-based entry pages also include wizards which are
  question-based, covering the most important decisions to filter
  through the respective materials. For example, the page on \"Data
  publication\" would include a repository wizard, asking about the
  research subject of the data to be published, the data type and
  size, if a certification of the repository is needed, etc. After
  answering the questions the user will get a result list that is
  respectively pre-filtered. The topic-based entry points also include
  overview articles that are relevant to the topic as well as related
  resources.

- A section with buttons into the different resource types (e.g.
  Repositories, Services, Tools/Software, Standards, Educational
  resources, Documents, Organisations) to cater to users who are
  mainly interested in one specific resource.

## Step 7: Mock-ups

Based on the results from the previous steps, OneStop4All mock-ups were
created. After an initial first sketch, the mock-ups were created using
the Figma software, which allowed us to create linkages between pages,
hover elements and many other design features. The mocks were a first
step in the design process of the OneStop4All and showed the most
important elements of the portal, such as how filtering and search
results would look like, as well as how the different resources within
NFDI4Earth could be easily accessed.

The layout and design of the mock-ups was heavily influenced by the
portal evaluations in Step 5. This aided us throughout he mock-up
creation by enabling us to see real examples of website functionalities
that are user friendly and intuitive and those that were not so easy to
navigate.

The header (Section 1) and footer elements (Section 8) of the site are
focused on providing the user with additional important information such
as links to FAQs and the User support network. Legal information about
the website is also available, along with information about the funding.
A log in area will also be available from the header.

The overall homepage ([@fig:homepage]) design is centred on the experience
levels of users i.e. a search bar (Section 2), linking directly to a
results list, is provided for experienced users, whereas a topic based
entry (Section 3) is provided for inexperienced users. For inexperienced
users, the topic based entry was based on the User Scenarios that were
created in step 4, focusing on the most common requirements of the
users.

Section 4 shows a list of all the resources provided by NFDI4Earth.

Section 5 allows the user to browse through the latest content on the
portal.

Section 6 shows how the user can get engaged with NFDI4Earth activity.

Section 7 is a statistics bar showing the user activity from different
elements of the portal e.g. number of questions answered, number of
active users. This section will not be included in the first version of
the OneStop4All.

![Homepage of the OneStop4All portal](homepage.png){#fig:homepage width="4.5in"}

Once a user uses the search bar they are brought to a search results
page ([@fig:searchresultspage]) with a number of filters. The filters are based off the
resource types in the OneStop4All as well as spatial and temporal
properties. The filters can also be expanded for a more refined search.

![Search results page](search-results-page.png){#fig:searchresultspage width="5.947915573053368in" height="5.427474846894138in"}

When a user selects one of the guided navigation buttons, they are
brought to a new page ([@fig:topicpage]) with direct links to a specific
resource, e.g. the repository finder, and with articles to help them
with this specific topic. An important element in the OneStop4All are
the linkages to related content. Once a user opens a result, they will
also be presented with links to content related to their result. This
not only aids the user with finding the information they are looking
for, but also encourages them to discover more OneStop4All content.

The mock-ups were then sent to the company 52°North, who are
responsible for the implementation of the site, so that they could begin
to create the final OneStop4All design.
The full set of mockups also included pages for the results list, e.g. on repository results only, a detail page on a single repository, the form to contact the user support network, and many more. They can be found in Appendix&nbsp;[@sec:mockups].

![Topic based entry page](topic-page.png){#fig:topicpage width="4.5in"}

The different steps of the OneStop4All development process offered
various possibilities for direct or implicit input from the community.
From the active contribution of user stories the most important topics
for the community were distilled as categories. The user stories were
also the basis for the personas as representations of user groups within
the community. Similarly, the user scenarios were developed from the
most important topics/categories from the user stories in combination
with the personas and exemplify the most important features and
functionalities that the OneStop4All needs to offer to be useful for ESS
users. All these building blocks, together with the portal evaluation,
went into the mock-ups. Various feedback rounds within the NFDI4Earth
consortium, at different steps in this development process, should
ensure that the variety of the 62 participating institutions and
disciplines as subset of the whole community could be satisfied with the
first version of the OneStop4All. Establishing a proper user feedback
group covering the diversity of the ESS community is the next step in
the community involvement. This feedback group will be asked to test the
first features in the portal so that the OneStop4All can be continuously
improved and adapted according to the community\'s needs.

\newpage

# References {-}

Anders, Ivonne, Hassler, Sibylle K., & Ryan, Marie. (2023). *NFDI4Earth- OneStop4All proto-personas* (v1.0). Zenodo. <https://doi.org/10.5281/zenodo.8367063>

Bernard, Lars, Braesicke, Peter, Bertelmann, Roland, Frickenhaus, Stephan, Gödde, Hildegard, Keßler, Carsten, Lorenz, Sören, Mahecha, Miguel, Marschall, Horst, Hezel, Dominik, Nagel, Wolfgang E., Reichstein, Markus, Sester, Monika, Thiemann, Hannes, Weiland, Claus, Wytzisk-Arens, Andreas, & NFDI Consortium Earth System Sciences. (2021). *NFDI Consortium Earth System Sciences - Proposal 2020 revised* (Revision 1 from 2021-10-01). Zenodo. <https://doi.org/10.5281/zenodo.5718944>

Butz, Andreas and Krüger, Antonio: *Mensch-Maschine-Interaktion*, Berlin, Boston: De Gruyter Oldenbourg, 2017. <https://doi.org/10.1515/9783110476378>

Cooper, Alan: *The Inmates Are Running the Asylum. Why High-Tech Products Drive Us Crazy and How to Restore the Sanity*. Indiana: Sams Publishing, 1999.

Cooper, Alan und Robert Reimann: *About Face 2.0. The Essentials of User Interface Design*. California: John Wiley & Sons, 1995.

Dam, Rikke Friis und Teo Yu Siang: *Personas -- A simple introduction.* <https://www.interaction-design.org/literature/article/personas-why-and-how-you-should-use-them>. Interaction Design Foundation. 2022.

Degbelo, Auriol, Frickenhaus, Stephan, Grieb, Jonas, Hachinger, Stephan, Henzen, Christin, Klammer, Ralf, Müller, Claudia, Munke, Johannes, Nüst, Daniel, Purr, Christopher, Weiland, Claus, & Wellmann, Alexander. (2023). *NFDI4Earth Software Architecture*. Zenodo. <https://doi.org/10.5281/zenodo.8333959>

Lorenz, Sören, Mehrtens, Hela, Getzlaff, Klaus, Munke, Johannes, & Müller-Pfefferkorn, Ralph. (2023). *Concept for the organisation of a distributed user support network (USN) in NFDI4Earth (NFDI4Earth Deliverable D2.2.1b)*. Zenodo. <https://doi.org/10.5281/zenodo.7912702>

Nielsen, J.: *The usability engineering life cycle*, Computer, 25(3), pp. 12--22. 1992. <https://doi.org/10.1109/2.121503>.

Norman, Donald. *"Ad-Hoc Personas & Empathetic Focus."* <https://jnd.org/ad-hoc-personas-empathetic-focus/>. 2008.

Norman, Donald: *Design of Everyday Things: Revised and Expanded.* New York: Basic Books. The UK edition is published by MIT Press, London. 2013

Jakobson, Jens (2017) *Website-Konzeption* dpunkt.verlag, 2017. ISBN: 978-3-86490-427-1

John Pruitt and Tamara Adlin. 2005. *The Persona Lifecycle: Keeping People in Mind Throughout Product Design.* Morgan Kaufmann Publishers Inc., San Francisco, CA, USA.

Schmitt, Robert H., Anthofer, Verena, Auer, Sören, Başkaya, Sait, Bischof, Christian, Bronger, Torsten, Claus, Florian, Cordes, Florian, Demandt, Évariste, Eifert, Thomas, Flemisch, Bernd, Fuchs, Matthias, Fuhrmans, Marc, Gerike, Regine, Gerstner, Eva-Maria, Hanke, Vanessa, Heine, Ina, Huebser, Louis, Iglezakis, Dorothea, ... Wang, Wei Min. (2020). *NFDI4Ing - the National Research Data Infrastructure for Engineering Sciences.* Zenodo. <https://doi.org/10.5281/zenodo.4015201>

\newpage

\appendix

# Appendix: User Scenarios {#sec:scenarios}

(content begins on next page)

\includepdf[pages=-]{OneStop4All DocumentationV4-appendix.pdf}

# Appendix: Mock-ups {#sec:mockups}

(content begins on next page)

\includepdf[pages=-]{OS4A-mockups.pdf}
